/************************************************************/
/* ALL SECTIONS OF THE CODE THAT REQUIRE EDITS ARE PRECEDED */
/* BY A COMMENT BOX LIKE THIS ONE AND BEGIN WITH "STEP #:"  */
/* PLEASE ONLY EDIT CODE AS INSTRUCTED BY COMMENT BOXES     */
/* ASSOCIATED WITH EACH STEP                                */
/************************************************************/

PROC DATASETS LIB = WORK KILL;
QUIT;


/* STEP 1: CHANGE DATAFILE LOCATION (SINGLE YEAR OR MERGED DUMMY DATA)*/
LIBNAME CHIS "D:\UCLA CHPR\Data\Dummy Data\CHIS 2020\ADULT_SAS_DUMMY_2020";

/* STEP 2: SET MASTER VARIABLE LIST LOCATION */
%let DPTAB = D:\UCLA CHRP\Code for Site\Dummy Data Prep\Final\CityofBerkley_MVL_2020.xlsx;



/* SET FINAL DATASET */
%let OUTFILE = "P:\Jason\Dummy data project\Dummy Data\FINAL_DUMMY_DATA";

/********************************************************************/
/*Import MVL Excel table */
/********************************************************************/

%MACRO xlimp(sheet);
PROC IMPORT OUT=PROXY_&SHEET DATAFILE="&DPTAB" DBMS=XLSX REPLACE; SHEET="&SHEET"; GETNAMES=YES; 
RUN;
%MEND;


/*********************************************************************************************************/
/* STEP 3: REMOVE UNEEDED LINES OF CODE                                                                  */
/* 	This step imports sheets from the MVL Excel tables. If you would like to produce separate datasets   */
/* 	for adult, teen, and child, please keep only the line(s) of code for the desired data set and remove */
/*  the other line(s)                                                                                    */
/*********************************************************************************************************/

%xlimp(ADULT);
%xlimp(TEEN);
%xlimp(CHILD);


/************************************************************************************************************/
/* STEP 4: REMOVE UNEEDED DATASETS                                                                          */
/*  This step combines the datasets that were imported in the last step. Remove the "PROXY_" dataset(s)     */
/*  from the "SET" statement that were not produced in the previous step                                    */
/************************************************************************************************************/

DATA APP_DATA; 
LENGTH VARIABLE_NAME $ 13;
SET PROXY_ADULT PROXY_TEEN PROXY_CHILD; 
RUN;


/****************************************************************************************************/
/*																									*/
/* PLEASE SKIP TO STEP 5 AT THE END OF THE CODE. DO NOT EDIT ANY CODE BETWEEN THIS POINT AND STEP 5 */
/*																									*/
/****************************************************************************************************/


/*The following steps create a dataset with only the selected variables*/
DATA MVLS; SET APP_DATA;
	IF whichc('X', of CHIS_2020--CHIS_2001) 
	OR whichc('x', of CHIS_2020--CHIS_2001)
	OR whichc('Y', of CHIS_2020--CHIS_2001)
	OR whichc('y', of CHIS_2020--CHIS_2001);
RUN;

DATA VAR_NAMES; 
	SET MVLS;
	KEEP VARIABLE_NAME;
RUN;

/*The following steps create a dataset with only the selected variables from PUF_RECODES sheet*/

PROC IMPORT OUT=PROXY_PUF
       DATAFILE="&DPTAB"
		   DBMS=XLSX REPLACE; SHEET="PUF RECODES"; GETNAMES=YES; 
RUN;

DATA PUF_MVLS; SET PROXY_PUF;
	IF WHICHC('X', of CHIS_2020--CHIS_2001) 
	OR WHICHC('x', of CHIS_2020--CHIS_2001)
	OR WHICHC('Y', of CHIS_2020--CHIS_2001)
	OR WHICHC('y', of CHIS_2020--CHIS_2001);
RUN;

DATA PUF_VAR_NAMES; 
	SET PUF_MVLS;
	KEEP VARIABLE_NAME ORIGINAL;
RUN;

/*The following steps remove selected variables that are not available in the dummy data
  and change puf names to original names if the original name is available in the dummy data*/

DATA VAR_CHECK1; SET VAR_NAMES;
	DSID = OPEN('CHIS.DUMMY_ADULT');
	IF VARNUM(DSID, VARIABLE_NAME) = 0 THEN DELETE;
RUN;

DATA VAR_CHECK2; SET PUF_VAR_NAMES;
	DSID = OPEN('CHIS.DUMMY_ADULT');
	IF VARNUM(DSID, ORIGINAL) = 0 THEN DO;
		IF (VARNUM(DSID, VARIABLE_NAME) = 0) THEN DELETE;
	END;
	ELSE VARIABLE_NAME = ORIGINAL;
RUN;

/*Combine all selected and available variables from all MVL file sheets and remove repeats*/
DATA ALL_VARS; 
	SET VAR_CHECK1 VAR_CHECK2; 
	KEEP VARIABLE_NAME; 
RUN;

PROC SQL NOPRINT; 
  SELECT DISTINCT VARIABLE_NAME INTO :PROXY1 SEPARATED BY ' ' FROM ALL_VARS; QUIT;

/*Check list to confirm all selected and available variables in MVL appear*/
%put &proxy1;

/*Following steps prepare dataset variables; removes variables not available to analyze


/*********************************************************************************/
/* STEP 5: CHANGE "COMBINED" TO NAME OF MERGED DATASET IN YOUR DIRECTORY         */
/*	NOTE: IF YOU ARE USING SINGLE YEAR DATA AND DO NOT HAVE A YEAR VARIABLE IN   */
/*  YOUR DUMMY DATA SET, REMOVE "YEAR" FROM THE "KEEP" STATEMENT                 */
/*********************************************************************************/

DATA FINAL;
	SET CHIS.COMBINED(KEEP=&proxy1 BASEID YEAR RAKEDW0-RAKEDW80);
RUN;


/***********************************************************************************/
/* STEP 6: Export datasets--SET OUTFILE LOCATION WITH FILE NAME FOR FINAL DATASET  */
/*  EXPORT TO STATA DATASET. USE CODE BELOW FOR SAS DATASET                        */
/***********************************************************************************/

PROC EXPORT DATA=WORK.FINAL
	OUTFILE = "&OUTFILE"
	dbms=dta;
RUN;

/**EXPORT TO SAS DATASET*/
LIBNAME OUT '&OUTFILE';
	DATA OUT.FINAL_DUMMY_DATA;
		SET FINAL;
RUN;
